function DBConvert(i)
% make directories
datasetdir = pwd; %please use the path where the NYU Depth dataset is;
rootdir = fullfile(pwd, 'data');
imgdir = fullfile(rootdir, 'image');
depthdir_fill = fullfile(rootdir, 'depth_fill');
normaldir = fullfile(rootdir, 'normal');
maskdir = fullfile(rootdir, 'mask');
if ~exist(imgdir,'dir'), mkdir(imgdir); end
if ~exist(depthdir_fill,'dir'), mkdir(depthdir_fill); end
if ~exist(normaldir,'dir'), mkdir(normaldir); end
if ~exist(maskdir,'dir'), mkdir(maskdir); end
% load NYU Depth dataset
nyu = matfile(fullfile(datasetdir, 'nyu_sample_800.mat'),'Writable',false);
% Depth Intrinsic Parameters
fx_d = 5.8262448167737955e+02;
fy_d = 5.8269103270988637e+02;
cx_d = 3.1304475870804731e+02;
cy_d = 2.3844389626620386e+02;
% %
% % ========== generate rgbd%d.mat ==========
% %  
images = nyu.images(:,:,:,i); %[4-D    uint8]                                                                         
rawDepths = nyu.rawDepths(:,:,i); %[3-D    single]
%get mask
[H,W] = size(rawDepths);
mask = false(H,W);
for tempH = 1:H
    for tempW = 1:W
        if rawDepths(tempH,tempW) == 0
            mask(tempH,tempW) = true;
        end
    end
end
%get x y z
[x_t,y_t] = meshgrid(1:W, 1:H);
z = double(rawDepths);
x = (x_t -cx_d) .* z ./ fx_d;
y = (y_t - cy_d) .* z ./ fy_d;   
%save mask map
maskName = [maskdir, filesep, 'mask', num2str(i,'%08d'), '.png'];
imwrite(mask,maskName,'png');
%save color map
colorName = [imgdir, filesep, 'color',num2str(i,'%08d'),'.png'];
imwrite(images,colorName,'png');% png color image
% fill depth
% PS: the source code of mex_cbf can be found in toolbox_nyu_depth_v2.
xx = fill_depth_cross_bfx(images, x, mask);
yy = fill_depth_cross_bfx(images, y, mask);
zz = fill_depth_cross_bfx(images, z, mask);
depthFilledName = [depthdir_fill, filesep, 'depthfill',num2str(i,'%08d'),'.mat'];    
save(depthFilledName, 'xx','yy','zz','mask');
%calculate the normal map
M = 15;
gv = fspecial('sobel'); %return a matrix 3 by 3
gh = gv';
hx = imfilter(xx, ones(M,M), 'replicate');
hy = imfilter(yy, ones(M,M), 'replicate');
hz = imfilter(zz, ones(M,M), 'replicate');
hx = imfilter(hx, gh, 'replicate');
hy = imfilter(hy, gh, 'replicate');
hz = imfilter(hz, gh, 'replicate');
hh = [hx(:), hy(:), hz(:)];

vx = imfilter(xx, ones(M,M), 'replicate');
vy = imfilter(yy, ones(M,M), 'replicate');
vz = imfilter(zz, ones(M,M), 'replicate');
vx = imfilter(vx, gv, 'replicate');
vy = imfilter(vy, gv, 'replicate');
vz = imfilter(vz, gv, 'replicate');
vv = [vx(:), vy(:), vz(:)];

rr = cross(hh, vv);
h = size(xx, 1);
w = size(xx, 2);
a = reshape(rr(:,1), h, w);
b = reshape(rr(:,2), h, w);
c = reshape(rr(:,3), h, w);
s = sqrt(a.*a + b.*b + c.*c + 1e-6);
a = a./s;
b = b./s;
c = c./s;

a = (a + 1)/2;
b = (b + 1)/2;
c = (c + 1)/2;

nm = cat(3, a, b, c);
%save normal maps
normalName = [normaldir, filesep, 'normal',num2str(i,'%08d'),'.ppm'];
imwrite(nm,normalName,'ppm');
end